==> nextcloud-28.0.14.tgz: nextcloud/apps/encryption/l10n/lv.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Pazudusi atkopšanas atslēgas parole",
    "Please repeat the recovery key password" : "Lūdzu atkārtot atgūšanas atslēgas paroli",
    "Repeated recovery key password does not match the provided recovery key password" : "Atkārtota atkopšanas atslēgas parole nesakrīt ar izsniegto atkopšanas atslēgu paroli",
    "Recovery key successfully enabled" : "Atkopšanas atslēga ir veiksmīgi iespējota",
    "Could not enable recovery key. Please check your recovery key password!" : "Atkopšanas atslēgu nevarēja iespējot. Lūdzu, pārbaudiet atkopšanas atslēgas paroli!",
    "Recovery key successfully disabled" : "Atkopšanas atslēga ir veiksmīgi deaktivizēta",
    "Could not disable recovery key. Please check your recovery key password!" : "Atkopšanas atslēgu nevarēja atspējot. Lūdzu, pārbaudiet atkopšanas atslēgas paroli!",
    "Missing parameters" : "Trūkstošos parametrs",
    "Please provide the old recovery password" : "Lūdzu, norādiet iepriekšējo atkopšanas paroli",
    "Please provide a new recovery password" : "Lūdzu, ievadiet jaunu paroli",
    "Please repeat the new recovery password" : "Lūdzu, atkārtojiet jauno atkopšanas paroli",
    "Password successfully changed." : "Parole veiksmīgi nomainīta.",
    "Could not change the password. Maybe the old password was not correct." : "Nevarēja mainīt paroli. Varbūt vecā parole nav pareiza.",
    "Recovery Key disabled" : "Atkopšanas atslēga deaktivizēta",
    "Recovery Key enabled" : "Atkopšanas atslēga aktivizēta",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nevarēja iespējot atkopšanas atslēgu. Lūgums mēģināt vēlreiz vai sazināties ar pārvaldītāju",
    "Could not update the private key password." : "Nevarēja atjaunināt privātās atslēgas paroli.",
    "The old password was not correct, please try again." : "Vecā parole nav pareiza, lūdzu, mēģiniet vēlreiz.",
    "The current log-in password was not correct, please try again." : "Pašreizējā pieteikšanās parole nebija pareiza, lūdzu, mēģiniet vēlreiz.",
    "Private key password successfully updated." : "Privātās atslēgas parole ir veiksmīgi atjaunināta.",
    "Encryption app is enabled and ready" : "Šifrēšanas lietotne ir iespējota un gatava",
    "Bad Signature" : "Nederīgs paraksts",
    "Missing Signature" : "Trūkst paraksta",
    "Change Password" : "Nomainīt paroli",
    "Your private key password no longer matches your log-in password." : "Privātās atslēgas parole vairs nesakrīt ar pieteikšanās paroli.",
    "Set your old private key password to your current log-in password:" : "Jānomaina sava vecā privātās atslēgas parole uz pašreizējo pieteikšanās paroli:",
    "Old log-in password" : "Vecā pieteikšanās parole",
    "Current log-in password" : "Pašreizējā pieteikšanās parole",
    "Update Private Key Password" : "Atjaunināt privātās atslēgas paroli",
    "Enable password recovery:" : "Iespējot paroles atjaunošanu:",
    "Enabled" : "Pievienots",
    "Disabled" : "Atspējots"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-29.0.11.tgz: nextcloud/apps/encryption/l10n/lv.js <==
OC.L10N.register(
    "encryption",
    {
    "Missing recovery key password" : "Pazudusi atkopšanas atslēgas parole",
    "Please repeat the recovery key password" : "Lūdzu atkārtot atgūšanas atslēgas paroli",
    "Repeated recovery key password does not match the provided recovery key password" : "Atkārtota atkopšanas atslēgas parole nesakrīt ar izsniegto atkopšanas atslēgu paroli",
    "Recovery key successfully enabled" : "Atkopšanas atslēga ir veiksmīgi iespējota",
    "Could not enable recovery key. Please check your recovery key password!" : "Atkopšanas atslēgu nevarēja iespējot. Lūdzu, pārbaudiet atkopšanas atslēgas paroli!",
    "Recovery key successfully disabled" : "Atkopšanas atslēga ir veiksmīgi deaktivizēta",
    "Could not disable recovery key. Please check your recovery key password!" : "Atkopšanas atslēgu nevarēja atspējot. Lūdzu, pārbaudiet atkopšanas atslēgas paroli!",
    "Missing parameters" : "Trūkstošos parametrs",
    "Please provide the old recovery password" : "Lūdzu, norādiet iepriekšējo atkopšanas paroli",
    "Please provide a new recovery password" : "Lūdzu, ievadiet jaunu paroli",
    "Please repeat the new recovery password" : "Lūdzu, atkārtojiet jauno atkopšanas paroli",
    "Password successfully changed." : "Parole veiksmīgi nomainīta.",
    "Could not change the password. Maybe the old password was not correct." : "Nevarēja mainīt paroli. Varbūt vecā parole nav pareiza.",
    "Recovery Key disabled" : "Atkopšanas atslēga deaktivizēta",
    "Recovery Key enabled" : "Atkopšanas atslēga aktivizēta",
    "Could not enable the recovery key, please try again or contact your administrator" : "Nevarēja iespējot atkopšanas atslēgu. Lūgums mēģināt vēlreiz vai sazināties ar pārvaldītāju",
    "Could not update the private key password." : "Nevarēja atjaunināt privātās atslēgas paroli.",
    "The old password was not correct, please try again." : "Vecā parole nebija pareiza, lūgums mēģināt vēlreiz.",
    "The current log-in password was not correct, please try again." : "Pašreizējā pieteikšanās parole nebija pareiza, lūgums mēģināt vēlreiz.",
    "Private key password successfully updated." : "Privātās atslēgas parole ir veiksmīgi atjaunināta.",
    "Encryption app is enabled and ready" : "Šifrēšanas lietotne ir iespējota un gatava",
    "Bad Signature" : "Nederīgs paraksts",
    "Missing Signature" : "Trūkst paraksta",
    "Change Password" : "Nomainīt paroli",
    "Your private key password no longer matches your log-in password." : "Privātās atslēgas parole vairs nesakrīt ar pieteikšanās paroli.",
    "Set your old private key password to your current log-in password:" : "Jānomaina sava vecā privātās atslēgas parole uz pašreizējo pieteikšanās paroli:",
    "Old log-in password" : "Vecā pieteikšanās parole",
    "Current log-in password" : "Pašreizējā pieteikšanās parole",
    "Update Private Key Password" : "Atjaunināt privātās atslēgas paroli",
    "Enable password recovery:" : "Iespējot paroles atjaunošanu:",
    "Enabled" : "Pievienots",
    "Disabled" : "Atspējots"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
